@@ -3,13 +3,23 @@
 from tensorflow.keras import backend as K
 
 
+def dice_loss(y_true, y_pred, smooth=100):
+    y_true_f = K.flatten(y_true)
+    y_pred_f = K.flatten(y_pred)
+    intersection = K.sum(y_true_f * y_pred_f)
+
+    dice = (2 * intersection + smooth) / (K.sum(y_true_f) + K.sum(y_pred_f) + smooth)
+
+    return 1 - dice
+
+
 def iou_loss(y_true, y_pred):
     """Computes the IoU for a single target class, then return a loss score between [0, 1].
 
     Args:
         y_true: tensor of ground-truth values of size (batch, height, width);
         y_pred: tensor of model predictions of size (batch, height, width)."""
-
+    # use tf.math.reduce_sum
     intersection = K.sum(K.flatten(y_true * y_pred))
     union = K.sum(K.flatten(y_true + y_pred - y_true * y_pred)) + 1
 
